/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Google Safe Browsing.
 *
 * The Initial Developer of the Original Code is Google Inc.
 * Portions created by the Initial Developer are Copyright (C) 2006
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Brett Wilson <brettw@gmail.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsISupports.idl"

interface nsIRequest;
interface nsIURI;


[scriptable, function, uuid(163f3437-1d69-4db7-9ce1-fd420fba8219)]
interface nsIDocNavStartProgressCallback : nsISupports
{
  void onDocNavStart(in nsIRequest aRequest, in AUTF8String aUri);
};

[scriptable, uuid(84991d1b-b010-4127-9e71-82017559abff)]
interface nsIDocNavStartProgressListener : nsISupports
{
  /**
   * Set to true to enable this component. Defaults to false (disabled). When
   * you set this to true, the listener will be attached to the docloader and
   * the callback can start getting events.
   */
  attribute boolean enabled;

  /**
   * Number of ms to wait after receiving a doc load event and calling the
   * callback.  Even when set to zero, we set a timer so the call will fire
   * asynchronously.  Defaults to 0.
   */
  attribute PRUint32 delay;

  /**
   * Callback object to be used when enabled=true.
   * NULL when there is no callback.
   */
  attribute nsIDocNavStartProgressCallback callback;

  /**
   * We ignore about:, chrome: and file: URIs.
   */
  boolean isSpurious(in nsIURI aURI);
};
