/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIFeedWriter.idl
 */

#ifndef __gen_nsIFeedWriter_h__
#define __gen_nsIFeedWriter_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIDOMWindow; /* forward declaration */


/* starting interface:    nsIFeedWriter */
#define NS_IFEEDWRITER_IID_STR "e4a39f75-93da-4264-8bf2-1a5bfb1f2f68"

#define NS_IFEEDWRITER_IID \
  {0xe4a39f75, 0x93da, 0x4264, \
    { 0x8b, 0xf2, 0x1a, 0x5b, 0xfb, 0x1f, 0x2f, 0x68 }}

/**
 * Instances of this component write UI into the display page. This component
 * is trusted so can access preferences etc, but page content isn't and so
 * cannot.
 */
class NS_NO_VTABLE nsIFeedWriter : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IFEEDWRITER_IID)

  /**
   * Write feed UI for a particular preview DOMWindow
   * @param   window
   *          The DOMWindow of the preview page that has loaded. 
   *          window.location.href == the URI of the feed.
   */
  /* void write (in nsIDOMWindow window); */
  NS_IMETHOD Write(nsIDOMWindow *window) = 0;

  /**
   * Uninitialize the feed writer.
   */
  /* void close (); */
  NS_IMETHOD Close(void) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIFEEDWRITER \
  NS_IMETHOD Write(nsIDOMWindow *window); \
  NS_IMETHOD Close(void); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIFEEDWRITER(_to) \
  NS_IMETHOD Write(nsIDOMWindow *window) { return _to Write(window); } \
  NS_IMETHOD Close(void) { return _to Close(); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIFEEDWRITER(_to) \
  NS_IMETHOD Write(nsIDOMWindow *window) { return !_to ? NS_ERROR_NULL_POINTER : _to->Write(window); } \
  NS_IMETHOD Close(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->Close(); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsFeedWriter : public nsIFeedWriter
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIFEEDWRITER

  nsFeedWriter();

private:
  ~nsFeedWriter();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsFeedWriter, nsIFeedWriter)

nsFeedWriter::nsFeedWriter()
{
  /* member initializers and constructor code */
}

nsFeedWriter::~nsFeedWriter()
{
  /* destructor code */
}

/* void write (in nsIDOMWindow window); */
NS_IMETHODIMP nsFeedWriter::Write(nsIDOMWindow *window)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void close (); */
NS_IMETHODIMP nsFeedWriter::Close()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIFeedWriter_h__ */
